@@ -1,8 +1,7 @@
 from aws_cdk import Stack 
 from constructs import Construct
 
-from cdk_toolkit import permission 
-from cdk_toolkit.permission import readIAMRolePolicyStatements
+from cdk_toolkit import permission  
 
 
 class IAMRolesStack(Stack): 
@@ -14,7 +13,7 @@ class IAMRolesStack(Stack):
 
         ##
         ## CodeBuild Service Role
-        codebuild_svc_role_dictionary = readIAMRolePolicyStatements(iam_roles_dir, "codebuild_svc_role")
+        codebuild_svc_role_dictionary = permission.readIAMRolePolicyStatements(iam_roles_dir, "codebuild_svc_role")
         self.codebuild_svc_role = permission.createIAMServiceRole(self, codebuild_svc_role_dictionary)
 
 
